@@ -1,4 +1,3 @@
-
 export default class TableModel {
   columns: any[];
   rows: any[];
@@ -45,4 +44,8 @@ export default class TableModel {
       this.columnMap[col.text] = col;
     }
   }
+
+  addRow(row) {
+    this.rows.push(row);
+  }
 }
