@@ -1,5 +1,3 @@
-///<reference path="../../headers/common.d.ts" />
-
 import _ from 'lodash';
 import coreModule from '../../core/core_module';
 
@@ -9,7 +7,7 @@ export class PlaylistsCtrl {
 
   /** @ngInject */
   constructor(private $scope, private backendSrv, navModelSrv) {
-    this.navModel = navModelSrv.getPlaylistsNav(0);
+    this.navModel = navModelSrv.getNav('dashboards', 'playlists', 0);
 
     backendSrv.get('/api/playlists').then(result => {
       this.playlists = result;
@@ -19,25 +17,26 @@ export class PlaylistsCtrl {
   removePlaylistConfirmed(playlist) {
     _.remove(this.playlists, { id: playlist.id });
 
-    this.backendSrv.delete('/api/playlists/' + playlist.id)
-    .then(() => {
+    this.backendSrv.delete('/api/playlists/' + playlist.id).then(
+      () => {
         this.$scope.appEvent('alert-success', ['Playlist deleted', '']);
-      }, () => {
+      },
+      () => {
         this.$scope.appEvent('alert-error', ['Unable to delete playlist', '']);
         this.playlists.push(playlist);
-      });
+      }
+    );
   }
 
   removePlaylist(playlist) {
-
     this.$scope.appEvent('confirm-modal', {
       title: 'Delete',
       text: 'Are you sure you want to delete playlist ' + playlist.name + '?',
-      yesText: "Delete",
-      icon: "fa-trash",
+      yesText: 'Delete',
+      icon: 'fa-trash',
       onConfirm: () => {
         this.removePlaylistConfirmed(playlist);
-      }
+      },
     });
   }
 }
