@@ -1,7 +1,5 @@
-///<reference path="../../headers/common.d.ts" />
-
 import kbn from 'app/core/utils/kbn';
-import {assignModelProperties} from 'app/core/core';
+import { assignModelProperties } from 'app/core/utils/model_utils';
 
 export interface Variable {
   setValue(option);
@@ -13,15 +11,13 @@ export interface Variable {
 }
 
 export var variableTypes = {};
-export {
-  assignModelProperties
-};
+export { assignModelProperties };
 
 export function containsVariable(...args: any[]) {
-  var variableName = args[args.length-1];
+  var variableName = args[args.length - 1];
   var str = args[0] || '';
 
-  for (var i = 1; i < args.length-1; i++) {
+  for (var i = 1; i < args.length - 1; i++) {
     str += ' ' + args[i] || '';
   }
 
@@ -30,8 +26,3 @@ export function containsVariable(...args: any[]) {
   var match = findVarRegex.exec(str);
   return match !== null;
 }
-
-
-
-
-
