@@ -1,5 +1,3 @@
-///<reference path="../../../headers/common.d.ts" />
-
 export class ConfigCtrl {
   static template = '';
 
@@ -14,7 +12,7 @@ export class ConfigCtrl {
     return this.backendSrv.get('/api/datasources').then(res => {
       var found = false;
       for (let ds of res) {
-        if (ds.type === "grafana-testdata-datasource") {
+        if (ds.type === 'grafana-testdata-datasource') {
           found = true;
         }
       }
@@ -24,7 +22,7 @@ export class ConfigCtrl {
           name: 'Grafana TestData',
           type: 'grafana-testdata-datasource',
           access: 'direct',
-          jsonData: {}
+          jsonData: {},
         };
 
         return this.backendSrv.post('/api/datasources', dsInstance);
@@ -34,4 +32,3 @@ export class ConfigCtrl {
     });
   }
 }
-
