@@ -1,19 +1,25 @@
 import angular from 'angular';
 import _ from 'lodash';
 import $ from 'jquery';
-import d3 from 'vendor/d3/d3';
-import {contextSrv} from 'app/core/core';
-import {tickStep} from 'app/core/utils/ticks';
+import * as d3 from 'd3';
+import { contextSrv } from 'app/core/core';
+import { tickStep } from 'app/core/utils/ticks';
+import { getColorScale, getOpacityScale } from './color_scale';
 
 let module = angular.module('grafana.directives');
 
+const LEGEND_HEIGHT_PX = 6;
+const LEGEND_WIDTH_PX = 100;
+const LEGEND_TICK_SIZE = 0;
+const LEGEND_VALUE_MARGIN = 0;
+
 /**
  * Color legend for heatmap editor.
  */
 module.directive('colorLegend', function() {
   return {
     restrict: 'E',
-    template: '<div class="heatmap-color-legend"><svg width="16.8rem" height="24px"></svg></div>',
+    template: '<div class="heatmap-color-legend"><svg width="16.5rem" height="24px"></svg></div>',
     link: function(scope, elem, attrs) {
       let ctrl = scope.ctrl;
       let panel = scope.ctrl.panel;
@@ -29,15 +35,17 @@ module.directive('colorLegend', function() {
         let legendWidth = Math.floor(legendElem.outerWidth());
 
         if (panel.color.mode === 'spectrum') {
-          let colorScheme = _.find(ctrl.colorSchemes, {value: panel.color.colorScheme});
-          let colorScale = getColorScale(colorScheme, legendWidth);
+          let colorScheme = _.find(ctrl.colorSchemes, {
+            value: panel.color.colorScheme,
+          });
+          let colorScale = getColorScale(colorScheme, contextSrv.user.lightTheme, legendWidth);
           drawSimpleColorLegend(elem, colorScale);
         } else if (panel.color.mode === 'opacity') {
           let colorOptions = panel.color;
           drawSimpleOpacityLegend(elem, colorOptions);
         }
       }
-    }
+    },
   };
 });
 
@@ -47,7 +55,7 @@ module.directive('colorLegend', function() {
 module.directive('heatmapLegend', function() {
   return {
     restrict: 'E',
-    template: '<div class="heatmap-color-legend"><svg width="100px" height="14px"></svg></div>',
+    template: `<div class="heatmap-color-legend"><svg width="${LEGEND_WIDTH_PX}px" height="${LEGEND_HEIGHT_PX}px"></svg></div>`,
     link: function(scope, elem, attrs) {
       let ctrl = scope.ctrl;
       let panel = scope.ctrl.panel;
@@ -66,7 +74,9 @@ module.directive('heatmapLegend', function() {
           let minValue = panel.color.min || 0;
 
           if (panel.color.mode === 'spectrum') {
-            let colorScheme = _.find(ctrl.colorSchemes, {value: panel.color.colorScheme});
+            let colorScheme = _.find(ctrl.colorSchemes, {
+              value: panel.color.colorScheme,
+            });
             drawColorLegend(elem, colorScheme, rangeFrom, rangeTo, maxValue, minValue);
           } else if (panel.color.mode === 'opacity') {
             let colorOptions = panel.color;
@@ -74,7 +84,7 @@ module.directive('heatmapLegend', function() {
           }
         }
       }
-    }
+    },
   };
 });
 
@@ -84,7 +94,7 @@ function drawColorLegend(elem, colorScheme, rangeFrom, rangeTo, maxValue, minVal
   clearLegend(elem);
 
   let legendWidth = Math.floor(legendElem.outerWidth()) - 30;
-  let legendHeight = legendElem.attr("height");
+  let legendHeight = legendElem.attr('height');
 
   let rangeStep = 1;
   if (rangeTo - rangeFrom > legendWidth) {
@@ -93,16 +103,18 @@ function drawColorLegend(elem, colorScheme, rangeFrom, rangeTo, maxValue, minVal
   let widthFactor = legendWidth / (rangeTo - rangeFrom);
   let valuesRange = d3.range(rangeFrom, rangeTo, rangeStep);
 
-  let colorScale = getColorScale(colorScheme, maxValue, minValue);
-  legend.selectAll(".heatmap-color-legend-rect")
+  let colorScale = getColorScale(colorScheme, contextSrv.user.lightTheme, maxValue, minValue);
+  legend
+    .selectAll('.heatmap-color-legend-rect')
     .data(valuesRange)
-    .enter().append("rect")
-    .attr("x", d => d * widthFactor)
-    .attr("y", 0)
-    .attr("width", rangeStep * widthFactor + 1) // Overlap rectangles to prevent gaps
-    .attr("height", legendHeight)
-    .attr("stroke-width", 0)
-    .attr("fill", d => colorScale(d));
+    .enter()
+    .append('rect')
+    .attr('x', d => d * widthFactor)
+    .attr('y', 0)
+    .attr('width', rangeStep * widthFactor + 1) // Overlap rectangles to prevent gaps
+    .attr('height', legendHeight)
+    .attr('stroke-width', 0)
+    .attr('fill', d => colorScale(d));
 
   drawLegendValues(elem, colorScale, rangeFrom, rangeTo, maxValue, minValue, legendWidth);
 }
@@ -113,23 +125,28 @@ function drawOpacityLegend(elem, options, rangeFrom, rangeTo, maxValue, minValue
   clearLegend(elem);
 
   let legendWidth = Math.floor(legendElem.outerWidth()) - 30;
-  let legendHeight = legendElem.attr("height");
+  let legendHeight = legendElem.attr('height');
 
-  let rangeStep = 10;
+  let rangeStep = 1;
+  if (rangeTo - rangeFrom > legendWidth) {
+    rangeStep = Math.floor((rangeTo - rangeFrom) / legendWidth);
+  }
   let widthFactor = legendWidth / (rangeTo - rangeFrom);
   let valuesRange = d3.range(rangeFrom, rangeTo, rangeStep);
 
   let opacityScale = getOpacityScale(options, maxValue, minValue);
-  legend.selectAll(".heatmap-opacity-legend-rect")
+  legend
+    .selectAll('.heatmap-opacity-legend-rect')
     .data(valuesRange)
-    .enter().append("rect")
-    .attr("x", d => d * widthFactor)
-    .attr("y", 0)
-    .attr("width", rangeStep * widthFactor)
-    .attr("height", legendHeight)
-    .attr("stroke-width", 0)
-    .attr("fill", options.cardColor)
-    .style("opacity", d => opacityScale(d));
+    .enter()
+    .append('rect')
+    .attr('x', d => d * widthFactor)
+    .attr('y', 0)
+    .attr('width', rangeStep * widthFactor)
+    .attr('height', legendHeight)
+    .attr('stroke-width', 0)
+    .attr('fill', options.cardColor)
+    .style('opacity', d => opacityScale(d));
 
   drawLegendValues(elem, opacityScale, rangeFrom, rangeTo, maxValue, minValue, legendWidth);
 }
@@ -142,25 +159,32 @@ function drawLegendValues(elem, colorScale, rangeFrom, rangeTo, maxValue, minVal
     return;
   }
 
-  let legendValueScale = d3.scaleLinear()
+  let legendValueScale = d3
+    .scaleLinear()
     .domain([0, rangeTo])
     .range([0, legendWidth]);
 
   let ticks = buildLegendTicks(0, rangeTo, maxValue, minValue);
-  let xAxis = d3.axisBottom(legendValueScale)
+  let xAxis = d3
+    .axisBottom(legendValueScale)
     .tickValues(ticks)
-    .tickSize(2);
+    .tickSize(LEGEND_TICK_SIZE);
 
-  let colorRect = legendElem.find(":first-child");
-  let posY = getSvgElemHeight(legendElem) + 2;
+  let colorRect = legendElem.find(':first-child');
+  let posY = getSvgElemHeight(legendElem) + LEGEND_VALUE_MARGIN;
   let posX = getSvgElemX(colorRect);
 
-  d3.select(legendElem.get(0)).append("g")
-    .attr("class", "axis")
-    .attr("transform", "translate(" + posX + "," + posY + ")")
+  d3
+    .select(legendElem.get(0))
+    .append('g')
+    .attr('class', 'axis')
+    .attr('transform', 'translate(' + posX + ',' + posY + ')')
     .call(xAxis);
 
-  legend.select(".axis").select(".domain").remove();
+  legend
+    .select('.axis')
+    .select('.domain')
+    .remove();
 }
 
 function drawSimpleColorLegend(elem, colorScale) {
@@ -168,23 +192,25 @@ function drawSimpleColorLegend(elem, colorScale) {
   clearLegend(elem);
 
   let legendWidth = Math.floor(legendElem.outerWidth());
-  let legendHeight = legendElem.attr("height");
+  let legendHeight = legendElem.attr('height');
 
   if (legendWidth) {
     let valuesNumber = Math.floor(legendWidth / 2);
-    let rangeStep  = Math.floor(legendWidth / valuesNumber);
+    let rangeStep = Math.floor(legendWidth / valuesNumber);
     let valuesRange = d3.range(0, legendWidth, rangeStep);
 
     let legend = d3.select(legendElem.get(0));
-    var legendRects = legend.selectAll(".heatmap-color-legend-rect").data(valuesRange);
+    var legendRects = legend.selectAll('.heatmap-color-legend-rect').data(valuesRange);
 
-    legendRects.enter().append("rect")
-      .attr("x", d => d)
-      .attr("y", 0)
-      .attr("width", rangeStep + 1) // Overlap rectangles to prevent gaps
-      .attr("height", legendHeight)
-      .attr("stroke-width", 0)
-      .attr("fill", d => colorScale(d));
+    legendRects
+      .enter()
+      .append('rect')
+      .attr('x', d => d)
+      .attr('y', 0)
+      .attr('width', rangeStep + 1) // Overlap rectangles to prevent gaps
+      .attr('height', legendHeight)
+      .attr('stroke-width', 0)
+      .attr('fill', d => colorScale(d));
   }
 }
 
@@ -194,32 +220,37 @@ function drawSimpleOpacityLegend(elem, options) {
 
   let legend = d3.select(legendElem.get(0));
   let legendWidth = Math.floor(legendElem.outerWidth());
-  let legendHeight = legendElem.attr("height");
+  let legendHeight = legendElem.attr('height');
 
   if (legendWidth) {
     let legendOpacityScale;
     if (options.colorScale === 'linear') {
-      legendOpacityScale = d3.scaleLinear()
-      .domain([0, legendWidth])
-      .range([0, 1]);
+      legendOpacityScale = d3
+        .scaleLinear()
+        .domain([0, legendWidth])
+        .range([0, 1]);
     } else if (options.colorScale === 'sqrt') {
-      legendOpacityScale = d3.scalePow().exponent(options.exponent)
-      .domain([0, legendWidth])
-      .range([0, 1]);
+      legendOpacityScale = d3
+        .scalePow()
+        .exponent(options.exponent)
+        .domain([0, legendWidth])
+        .range([0, 1]);
     }
 
     let rangeStep = 10;
     let valuesRange = d3.range(0, legendWidth, rangeStep);
-    var legendRects = legend.selectAll(".heatmap-opacity-legend-rect").data(valuesRange);
+    var legendRects = legend.selectAll('.heatmap-opacity-legend-rect').data(valuesRange);
 
-    legendRects.enter().append("rect")
-      .attr("x", d => d)
-      .attr("y", 0)
-      .attr("width", rangeStep)
-      .attr("height", legendHeight)
-      .attr("stroke-width", 0)
-      .attr("fill", options.cardColor)
-      .style("opacity", d => legendOpacityScale(d));
+    legendRects
+      .enter()
+      .append('rect')
+      .attr('x', d => d)
+      .attr('y', 0)
+      .attr('width', rangeStep)
+      .attr('height', legendHeight)
+      .attr('stroke-width', 0)
+      .attr('fill', options.cardColor)
+      .style('opacity', d => legendOpacityScale(d));
   }
 }
 
@@ -228,31 +259,6 @@ function clearLegend(elem) {
   legendElem.empty();
 }
 
-function getColorScale(colorScheme, maxValue, minValue = 0) {
-  let colorInterpolator = d3[colorScheme.value];
-  let colorScaleInverted = colorScheme.invert === 'always' ||
-    (colorScheme.invert === 'dark' && !contextSrv.user.lightTheme);
-
-  let start = colorScaleInverted ? maxValue : minValue;
-  let end = colorScaleInverted ? minValue : maxValue;
-
-  return d3.scaleSequential(colorInterpolator).domain([start, end]);
-}
-
-function getOpacityScale(options, maxValue, minValue = 0) {
-  let legendOpacityScale;
-  if (options.colorScale === 'linear') {
-    legendOpacityScale = d3.scaleLinear()
-    .domain([minValue, maxValue])
-    .range([0, 1]);
-  } else if (options.colorScale === 'sqrt') {
-    legendOpacityScale = d3.scalePow().exponent(options.exponent)
-    .domain([minValue, maxValue])
-    .range([0, 1]);
-  }
-  return legendOpacityScale;
-}
-
 function getSvgElemX(elem) {
   let svgElem = elem.get(0);
   if (svgElem && svgElem.x && svgElem.x.baseVal) {
